<!-- #build0 -->
# bench plugin

## Docker Run

Run the Docker image using the `docker run` command, now including the `CMS_TYPE` environment variable for CMS-specific authentication:

1. **Testing a Single URL with Concrete5 Authentication:**

    ```bash
    docker run -e CMS_TYPE="Concrete5" -e URLS="http://example.com" -e USERNAME="user" -e PASSWORD="pass" git.nixc.us/colin/bench:production
    ```

2. **Testing Multiple URLs with Concrete5 Authentication:**

    ```bash
    docker run -e CMS_TYPE="Concrete5" -e URLS="http://example.com,http://example2.com" -e USERNAME="user" -e PASSWORD="pass" git.nixc.us/colin/bench:production
    ```

### Docker Compose

Example `docker-compose.yml` file, now with `CMS_TYPE` to specify the CMS for authentication:

```yaml
version: '3'

services:
  apachebench:
    image: git.nixc.us/colin/bench:production
    environment:
      CMS_TYPE: "Concrete5" # Specify CMS type for authentication
      URLS: "http://example.com,http://example2.com" # Comma-separated list of URLs
      USERNAME: "user" # Basic auth username
      PASSWORD: "pass" # Basic auth password
      REQUESTS: 100 # Number of requests for Apache Bench
      CONCURRENCY: 10 # Number of multiple requests to make at a time
```

Run the service defined in the `docker-compose.yml` file with:

```bash
docker-compose up
```

## Customizing the Configuration

To fine-tune your testing setup, adjust the following environment variables:

- `CMS_TYPE`: Specify the CMS type for CMS-specific authentication (e.g., "Concrete5").
- `URLS`: Comma-separated list of URLs to test.
- `USERNAME` and `PASSWORD`: Credentials for HTTP Basic Authentication.
- `REQUESTS`: Number of requests to perform with Apache Bench.
- `CONCURRENCY`: Number of multiple requests to make at a time.